@@ -33,6 +33,8 @@ package jdk.internal.loader;
 
 import com.ibm.sharedclasses.spi.SharedClassProvider; 				//OpenJ9-shared_classes_misc
 
+import java.io.File;
+import java.io.FilePermission;
 import java.io.IOException;
 import java.io.InputStream;
 import java.lang.module.ModuleDescriptor;
@@ -50,6 +52,7 @@ import java.security.AccessControlException;
 import java.security.AccessController;
 import java.security.CodeSigner;
 import java.security.CodeSource;
+import java.security.Permission;
 import java.security.PermissionCollection;
 import java.security.PrivilegedAction;
 import java.security.PrivilegedActionException;
@@ -76,7 +79,6 @@ import jdk.internal.misc.VM;
 import jdk.internal.module.ModulePatcher.PatchedModuleReader;
 import jdk.internal.module.Resources;
 import jdk.internal.vm.annotation.Stable;
-import sun.security.util.LazyCodeSourcePermissionCollection;
 
 
 /**
@@ -1283,9 +1285,39 @@ public class BuiltinClassLoader
      */
     @Override
     protected PermissionCollection getPermissions(CodeSource cs) {
-        return new LazyCodeSourcePermissionCollection(super.getPermissions(cs), cs);
+        PermissionCollection perms = super.getPermissions(cs);
+
+        // add the permission to access the resource
+        URL url = cs.getLocation();
+        if (url == null)
+            return perms;
+
+        // avoid opening connection when URL is to resource in run-time image
+        if (url.getProtocol().equals("jrt")) {
+            perms.add(new RuntimePermission("accessSystemModules"));
+            return perms;
+        }
+
+        // open connection to determine the permission needed
+        try {
+            Permission p = url.openConnection().getPermission();
+            if (p != null) {
+                // for directories then need recursive access
+                if (p instanceof FilePermission) {
+                    String path = p.getName();
+                    if (path.endsWith(File.separator)) {
+                        path += "-";
+                        p = new FilePermission(path, "read");
+                    }
+                }
+                perms.add(p);
+            }
+        } catch (IOException ioe) { }
+
+        return perms;
     }
 
+
     // -- miscellaneous supporting methods
 
     /**
